@@ -24,6 +24,7 @@
 #include <KItinerary/Action>
 #include <KItinerary/Brand>
 #include <KItinerary/BusTrip>
+#include <KItinerary/CreativeWork>
 #include <KItinerary/Event>
 #include <KItinerary/Flight>
 #include <KItinerary/Organization>
@@ -51,7 +52,7 @@ using namespace KItinerary;
 static QVariant createInstance(const QJsonObject &obj);
 
 // Eurowings workarounds...
-static const char *fallbackDateTimePattern[] = {
+static const char* const fallbackDateTimePattern[] = {
     "yyyy-MM-dd HH:mm:ss",
     "yyyy-MM-dd HH:mm",
     "MM-dd-yyyy HH:mm", // yes, seriously ;(
@@ -122,9 +123,13 @@ static QVariant propertyValue(const QMetaProperty &prop, const QJsonValue &v)
             const auto array = v.toArray();
             l.reserve(array.size());
             for (const auto &elem : array) {
-                const auto var = createInstance(elem.toObject());
-                if (!var.isNull()) {
-                    l.push_back(var);
+                if (elem.isObject()) {
+                    const auto var = createInstance(elem.toObject());
+                    if (!var.isNull()) {
+                        l.push_back(var);
+                    }
+                } else if (elem.isString()) {
+                    l.push_back(elem.toString());
                 }
             }
         }
@@ -175,7 +180,10 @@ static QVariant createInstance(const QJsonObject &obj)
     MAKE_FACTORY(BusTrip);
     MAKE_FACTORY(CancelAction);
     MAKE_FACTORY(CheckInAction);
+    MAKE_FACTORY(CreativeWork);
+    MAKE_FACTORY(DigitalDocument);
     MAKE_FACTORY(DownloadAction);
+    MAKE_FACTORY(EmailMessage);
     MAKE_FACTORY(Event);
     MAKE_FACTORY(EventReservation);
     MAKE_FACTORY(Flight);
@@ -184,6 +192,7 @@ static QVariant createInstance(const QJsonObject &obj)
     MAKE_FACTORY(FoodEstablishmentReservation);
     MAKE_FACTORY(RentalCarReservation);
     MAKE_FACTORY(RentalCar);
+    MAKE_FACTORY(ReserveAction);
     MAKE_FACTORY(GeoCoordinates);
     MAKE_FACTORY(LodgingBusiness);
     MAKE_FACTORY(LodgingReservation);
